@@ -32,11 +32,12 @@ cd src
 echo "Applying astyle rules..."
 astyle \
 --indent=spaces=4 \
---brackets=break \
+--style=allman \
 --indent-labels \
---pad=oper \
---unpad=paren \
---one-line=keep-statements \
+--pad-oper \
+--pad-header \
+--unpad-paren \
+--keep-one-line-statements \
 --convert-tabs \
 --indent-preprocessor \
 `find -type f -name '*.cpp'` `find -type f -name '*.h'`
