@@ -30,9 +30,12 @@
 // Rekonq Includes
 #include "rekonq_defines.h"
 
+// Qt Includes
+#include <QNetworkRequest>
+
 
 AdBlockRuleTextMatchImpl::AdBlockRuleTextMatchImpl(const QString &filter)
-        : AdBlockRuleImpl(filter)
+    : AdBlockRuleImpl(filter)
 {
     Q_ASSERT(AdBlockRuleTextMatchImpl::isTextMatchFilter(filter));
 
@@ -43,8 +46,8 @@ AdBlockRuleTextMatchImpl::AdBlockRuleTextMatchImpl(const QString &filter)
 
 bool AdBlockRuleTextMatchImpl::match(const QNetworkRequest &request, const QString &encodedUrl, const QString &encodedUrlLowerCase) const
 {
-    Q_UNUSED(encodedUrl);
     Q_UNUSED(request);
+    Q_UNUSED(encodedUrl);
     // Case sensitive compare is faster, but would be incorrect with encodedUrl since
     // we do want case insensitive.
     // What we do is work on a lowercase version of m_textToMatch, and compare to the lowercase
