@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2008-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2008-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2009 by Paweł Prażak <pawelprazak at gmail dot com>
 * Copyright (C) 2009-2011 by Lionel Chauvin <megabigbug@yahoo.fr>
 *
@@ -43,15 +43,18 @@
 #include <QtCore/QDateTime>
 #include <QtCore/QWeakPointer>
 
+
 // Forward Declarations
 class AdBlockManager;
-class BookmarkProvider;
+class BookmarkManager;
 class DownloadManager;
 class HistoryManager;
 class IconManager;
 class MainWindow;
 class OpenSearchManager;
 class SessionManager;
+class UserAgentManager;
+class SyncManager;
 
 class KAction;
 
@@ -88,19 +91,21 @@ public:
     MainWindowList mainWindowList();
 
     HistoryManager *historyManager();
-    BookmarkProvider *bookmarkProvider();
+    BookmarkManager *bookmarkManager();
     SessionManager *sessionManager();
     AdBlockManager *adblockManager();
     OpenSearchManager *opensearchManager();
     IconManager *iconManager();
     DownloadManager *downloadManager();
+    UserAgentManager *userAgentManager();
+    SyncManager *syncManager();
 
     KAction *privateBrowsingAction()
     {
         return _privateBrowsingAction;
     };
 
-public slots:
+public Q_SLOTS:
     /**
      * Save application's configuration
      *
@@ -119,7 +124,7 @@ protected:
     // This is used to track which window was activated most recently
     bool eventFilter(QObject *watched, QEvent *event);
 
-private slots:
+private Q_SLOTS:
     void loadResolvedUrl(ThreadWeaver::Job *);
 
     void updateConfiguration();
@@ -129,14 +134,18 @@ private slots:
 
     void queryQuit();
 
+    void createWebAppShortcut();
+
 private:
     QWeakPointer<HistoryManager> m_historyManager;
-    QWeakPointer<BookmarkProvider> m_bookmarkProvider;
+    QWeakPointer<BookmarkManager> m_bookmarkManager;
     QWeakPointer<SessionManager> m_sessionManager;
     QWeakPointer<AdBlockManager> m_adblockManager;
     QWeakPointer<OpenSearchManager> m_opensearchManager;
     QWeakPointer<IconManager> m_iconManager;
     QWeakPointer<DownloadManager> m_downloadManager;
+    QWeakPointer<UserAgentManager> m_userAgentManager;
+    QWeakPointer<SyncManager> m_syncManager;
 
     MainWindowList m_mainWindows;
 
