@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2008-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2008-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2009 by Paweł Prażak <pawelprazak at gmail dot com>
 * Copyright (C) 2009-2011 by Lionel Chauvin <megabigbug@yahoo.fr>
 * Copyright (C) 2010 by Matthieu Gicquel <matgic78 at gmail dot com>
@@ -106,18 +106,27 @@ public:
         return m_recentlyClosedTabs;
     }
 
+    void restoreClosedTab(int i, bool inNewTab = true);
+
 Q_SIGNALS:
     // current tab signals
     void currentTitle(const QString &url);
     void showStatusBarMessage(const QString &message, Rekonq::Notify status = Rekonq::Info);
     void linkHovered(const QString &link);
-    void browserTabLoading(bool);
     void openPreviousInHistory();
     void openNextInHistory();
     void closeWindow();
 
     void printRequested(QWebFrame *frame);
 
+    /**
+     * Current tab state changed:
+     *  1. tab is loading
+     *  2. tab finished loading
+     *  3. tab urlbar got focus
+     */
+    void currentTabStateChanged();
+
 public Q_SLOTS:
     /**
      * Core browser slot. This create a new tab with a WebView inside
@@ -144,8 +153,6 @@ public Q_SLOTS:
     void nextTab();
     void previousTab();
 
-    void openLastClosedTab();
-    void openClosedTab();
     void switchToTab(const int index);
     void loadFavorite(const int index);
 
@@ -164,6 +171,8 @@ private Q_SLOTS:
 
     void windowCloseRequested();
 
+    void openClosedTab();
+
 protected:
     virtual void resizeEvent(QResizeEvent *event);
 
