@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2010 by Matthieu Gicquel <matgic78 at gmail dot com>
 *
 *
@@ -34,11 +34,13 @@
 
 // Local Includes
 #include "application.h"
-#include "bookmarkprovider.h"
+#include "bookmarkmanager.h"
 #include "downloadmanager.h"
+#include "iconmanager.h"
 #include "historymodels.h"
 #include "mainview.h"
 #include "mainwindow.h"
+#include "previewselectorbar.h"
 #include "websnap.h"
 #include "webpage.h"
 #include "webtab.h"
@@ -51,9 +53,9 @@
 #include <KStandardDirs>
 
 // Qt Includes
-#include <QtCore/QFile>
-#include <QtGui/QAction>
-#include <QtWebKit/QWebFrame>
+#include <QFile>
+#include <QAction>
+#include <QWebFrame>
 
 
 NewTabPage::NewTabPage(QWebFrame *frame)
@@ -79,6 +81,7 @@ NewTabPage::NewTabPage(QWebFrame *frame)
 
 void NewTabPage::generate(const KUrl &url)
 {
+    // about:preview links
     if (KUrl("about:preview").isParentOf(url))
     {
         if (url.fileName() == QL1S("add"))
@@ -86,6 +89,8 @@ void NewTabPage::generate(const KUrl &url)
             QStringList names = ReKonfig::previewNames();
             QStringList urls = ReKonfig::previewUrls();
 
+            int index = urls.count();
+
             names.append("");
             urls.append("");
 
@@ -94,8 +99,10 @@ void NewTabPage::generate(const KUrl &url)
 
             // Why doesn't it work well ?
             // m_root.appendInside(emptyPreview(names.length() - 1));
-            // Replacing with this :
+            // Replacing with this:
             generate(KUrl("about:favorites"));
+
+            rApp->mainWindow()->currentTab()->createPreviewSelectorBar(index);
             return;
         }
         if (url.directory() == QL1S("preview/remove"))
@@ -110,26 +117,85 @@ void NewTabPage::generate(const KUrl &url)
             return;
         }
     }
-    if (url.fileName() == QL1S("clear"))
+
+    // about:tabs links
+    if (KUrl("about:tabs").isParentOf(url))
     {
-        rApp->mainWindow()->actionByName("clear_private_data")->trigger();
-        generate(QString(QL1S("about:") + url.directory()));
+        if (url.fileName() == QL1S("show"))
+        {
+            const int winIndex = url.queryItem(QL1S("win")).toInt();
+            const int tabIndex = url.queryItem(QL1S("tab")).toInt();
+            kDebug() << "win = " << winIndex;
+            kDebug() << "tab = " << tabIndex;
+
+            MainWindow *w = rApp->mainWindowList().at(winIndex).data();
+
+            // close about:tabs tab
+            rApp->mainWindow()->mainView()->closeTab(rApp->mainWindow()->mainView()->currentIndex());
+
+            // show requested tab
+            w->mainView()->setCurrentIndex(tabIndex);
+            if (w != rApp->mainWindow())
+                w->raise();
+            return;
+        }
+
+        if (url.fileName() == QL1S("remove"))
+        {
+            const int winIndex = url.queryItem(QL1S("win")).toInt();
+            const int tabIndex = url.queryItem(QL1S("tab")).toInt();
+            kDebug() << "win = " << winIndex;
+            kDebug() << "tab = " << tabIndex;
+
+            MainWindow *w = rApp->mainWindowList().at(winIndex).data();
+            w->mainView()->closeTab(tabIndex);
+            generate(KUrl("about:tabs"));
+            return;
+        }
+    }
+
+    // about:closedTabs links
+    if (KUrl("about:closedTabs").isParentOf(url))
+    {
+        if (url.fileName() == QL1S("restore"))
+        {
+            const int tabIndex = url.queryItem(QL1S("tab")).toInt();
+            kDebug() << "tab = " << tabIndex;
+
+            rApp->mainWindow()->mainView()->restoreClosedTab(tabIndex, false);
+            return;
+        }
+    }
+
+    if (url == KUrl("about:downloads/clear"))
+    {
+        rApp->downloadManager()->clearDownloadsHistory();
+        generate(KUrl("about:downloads"));
+        return;
+    }
+    if (url == KUrl("about:history/clear"))
+    {
+        rApp->historyManager()->clear();
+        generate(KUrl("about:history"));
         return;
     }
     if (url == KUrl("about:bookmarks/edit"))
     {
-        rApp->bookmarkProvider()->bookmarkManager()->slotEditBookmarks();
+        rApp->bookmarkManager()->slotEditBookmarks();
         return;
     }
 
     // webFrame can be null. See bug:282092
-    if (!m_root.webFrame())
+    QWebFrame *parentFrame = qobject_cast<QWebFrame *>(parent());
+    if (!parentFrame)
+    {
+        kDebug() << "NULL PARENT FRAME: PAGE NOT LOADED";
         return;
-    WebPage *page = qobject_cast <WebPage *>(m_root.webFrame()->page());
-    page->mainFrame()->setHtml(m_html);
-    page->setIsOnRekonqPage(true);
+    }
 
-    m_root = page->mainFrame()->documentElement().findFirst(QL1S("#content"));
+    parentFrame->setHtml(m_html);
+
+    m_root = parentFrame->documentElement().findFirst(QL1S("#content"));
 
     browsingMenu(url);
 
@@ -165,181 +231,19 @@ void NewTabPage::generate(const KUrl &url)
         updateWindowIcon();
         title = i18n("Downloads");
     }
+    else if (encodedUrl == QByteArray("about:tabs"))
+    {
+        tabsPage();
+        updateWindowIcon();
+        title = i18n("Tabs");
+    }
 
     m_root.document().findFirst(QL1S("title")).setPlainText(title);
 }
 
 
-void NewTabPage::favoritesPage()
-{
-    m_root.addClass(QL1S("favorites"));
-
-    const QWebElement add = createLinkItem(i18n("Add Favorite"),
-                                           QL1S("about:preview/add"),
-                                           QL1S("list-add"),
-                                           KIconLoader::Toolbar);
-    m_root.document().findFirst("#actions").appendInside(add);
-
-    QStringList names = ReKonfig::previewNames();
-    QStringList urls = ReKonfig::previewUrls();
-
-    if (urls.isEmpty())
-    {
-        m_root.addClass(QL1S("empty"));
-        m_root.setPlainText(i18n("You can add a favorite by clicking the \"Add Favorite\" button in the top-right corner of this page"));
-        return;
-    }
-
-    for (int i = 0; i < urls.count() ; ++i)
-    {
-        KUrl url = KUrl(urls.at(i));
-        QWebElement prev;
-
-        if (url.isEmpty())
-            prev = emptyPreview(i);
-        else if (!WebSnap::existsImage(url))
-            prev = loadingPreview(i, url);
-        else
-            prev = validPreview(i, url, QString::number(i + 1) + " - " + names.at(i));
-
-        setupPreview(prev, i);
-
-        m_root.appendInside(prev);
-    }
-}
-
-
-QWebElement NewTabPage::emptyPreview(int index)
-{
-    QWebElement prev = markup(QL1S(".thumbnail"));
-
-    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") ,
-            QL1S("file:///") + KIconLoader::global()->iconPath("insert-image", KIconLoader::Desktop));
-    prev.findFirst(QL1S("span a")).setPlainText(i18n("Set a Preview..."));
-    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"),
-                                           QL1S("about:preview/modify/") + QVariant(index).toString());
-
-    setupPreview(prev, index);
-    //hideControls(prev);
-
-    return prev;
-}
-
-
-QWebElement NewTabPage::loadingPreview(int index, const KUrl &url)
-{
-    QWebElement prev = markup(QL1S(".thumbnail"));
-
-    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src"),
-            QL1S("file:///") + KStandardDirs::locate("appdata", "pics/busywidget.gif"));
-    prev.findFirst(QL1S("span a")).setPlainText(i18n("Loading Preview..."));
-    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), url.toMimeDataString());
-
-    setupPreview(prev, index);
-    showControls(prev);
-
-    // NOTE: we need the page frame for two reasons
-    // 1) to link to the WebPage calling the snapFinished slot
-    // 2) to "auto-destroy" snaps on tab closing :)
-    QWebFrame *frame = qobject_cast<QWebFrame *>(parent());
-    WebSnap *snap = new WebSnap(url, frame);
-    connect(snap, SIGNAL(snapDone(bool)), frame->page(), SLOT(updateImage(bool)), Qt::UniqueConnection);
-    return prev;
-}
-
-
-QWebElement NewTabPage::validPreview(int index, const KUrl &url, const QString &title)
-{
-    QWebElement prev = markup(QL1S(".thumbnail"));
-    QString previewPath = QL1S("file://") + WebSnap::imagePathFromUrl(url);
-
-    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") , previewPath);
-    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), url.toMimeDataString());
-    prev.findFirst(QL1S("span a")).setAttribute(QL1S("href"), url.toMimeDataString());
-    prev.findFirst(QL1S("span a")).setPlainText(checkTitle(title));
-
-    setupPreview(prev, index);
-    showControls(prev);
-    return prev;
-}
-
-
-void NewTabPage::hideControls(QWebElement e)
-{
-    e.findFirst(QL1S(".remove")).setStyleProperty(QL1S("visibility"), QL1S("hidden"));
-    e.findFirst(QL1S(".modify")).setStyleProperty(QL1S("visibility"), QL1S("hidden"));
-}
-
-
-void NewTabPage::showControls(QWebElement e)
-{
-    e.findFirst(QL1S(".remove")).setStyleProperty(QL1S("visibility"), QL1S("visible"));
-    e.findFirst(QL1S(".modify")).setStyleProperty(QL1S("visibility"), QL1S("visible"));
-}
-
-
-void NewTabPage::setupPreview(QWebElement e, int index)
-{
-    e.findFirst(QL1S(".remove img")).setAttribute(QL1S("src"), QL1S("file:///") + KIconLoader::global()->iconPath("edit-delete", KIconLoader::DefaultState));
-    e.findFirst(QL1S(".remove")).setAttribute(QL1S("title"), QL1S("Remove favorite"));
-    e.findFirst(QL1S(".modify img")).setAttribute(QL1S("src"), QL1S("file:///") + KIconLoader::global()->iconPath("insert-image", KIconLoader::DefaultState));
-    e.findFirst(QL1S(".modify")).setAttribute(QL1S("title"), QL1S("Set new favorite"));
-
-    e.findFirst(QL1S(".modify")).setAttribute(QL1S("href"), QL1S("about:preview/modify/") + QVariant(index).toString());
-    e.findFirst(QL1S(".remove")).setAttribute(QL1S("href"), QL1S("about:preview/remove/") + QVariant(index).toString());
-
-    e.setAttribute(QL1S("id"), QL1S("preview") + QVariant(index).toString());
-}
-
-
-void NewTabPage::snapFinished()
-{
-    // Update page, but only if open
-    if (m_root.document().findAll(QL1S("#rekonq-newtabpage")).count() == 0)
-        return;
-    if (m_root.findAll(QL1S(".favorites")).count() == 0 && m_root.findAll(QL1S(".closedTabs")).count() == 0)
-        return;
-
-    QStringList urls = ReKonfig::previewUrls();
-    QStringList names = ReKonfig::previewNames();
-
-    for (int i = 0; i < urls.count(); i++)
-    {
-        KUrl url = KUrl(urls.at(i));
-        QString title = names.at(i);
-
-        if (WebSnap::existsImage(url))
-        {
-            QWebElement prev = m_root.findFirst(QL1S("#preview") + QVariant(i).toString());
-            if (KUrl(prev.findFirst("a").attribute(QL1S("href"))) == url)
-            {
-                QWebElement newPrev = validPreview(i, url, title);
-
-                if (m_root.findAll(QL1S(".closedTabs")).count() != 0)
-                    hideControls(newPrev);
-
-                prev.replace(newPrev);
-            }
-        }
-    }
-}
-
-
-void NewTabPage::removePreview(int index)
-{
-    QStringList names = ReKonfig::previewNames();
-    QStringList urls = ReKonfig::previewUrls();
-
-    urls.removeAt(index);
-    names.removeAt(index);
-
-    ReKonfig::setPreviewNames(names);
-    ReKonfig::setPreviewUrls(urls);
-
-    generate(KUrl("about:favorites"));
-
-    ReKonfig::self()->writeConfig();
-}
+// ----------------------------------------------------------------------------
+// HIGH-LEVEL FUNCTIONS
 
 
 void NewTabPage::browsingMenu(const KUrl &currentUrl)
@@ -376,7 +280,13 @@ void NewTabPage::browsingMenu(const KUrl &currentUrl)
                                    QL1S("download"),
                                    KIconLoader::Toolbar));
 
-    foreach(QWebElement it, navItems)
+    // Tabs
+    navItems.append(createLinkItem(i18n("Tabs"),
+                                   QL1S("about:tabs"),
+                                   QL1S("tab-duplicate"),
+                                   KIconLoader::Toolbar));
+
+    Q_FOREACH(QWebElement it, navItems)
     {
         const QString aTagString(QL1C('a'));
         const QString hrefAttributeString(QL1S("href"));
@@ -390,15 +300,48 @@ void NewTabPage::browsingMenu(const KUrl &currentUrl)
 }
 
 
+void NewTabPage::favoritesPage()
+{
+    m_root.addClass(QL1S("favorites"));
+
+    const QWebElement add = createLinkItem(i18n("Add Favorite"),
+                                           QL1S("about:preview/add"),
+                                           QL1S("list-add"),
+                                           KIconLoader::Toolbar);
+    m_root.document().findFirst("#actions").appendInside(add);
+
+    QStringList names = ReKonfig::previewNames();
+    QStringList urls = ReKonfig::previewUrls();
+
+    if (urls.isEmpty())
+    {
+        m_root.addClass(QL1S("empty"));
+        m_root.setPlainText(i18n("You can add a favorite by clicking the \"Add Favorite\" button in the top-right corner of this page"));
+        return;
+    }
+
+    for (int i = 0; i < urls.count() ; ++i)
+    {
+        KUrl url = KUrl(urls.at(i));
+
+        QWebElement prev = url.isEmpty()
+                           ? emptyPreview(i)
+                           : validPreview(i, url, QString::number(i + 1) + " - " + names.at(i));
+
+        m_root.appendInside(prev);
+    }
+}
+
+
 void NewTabPage::historyPage()
 {
     m_root.addClass(QL1S("history"));
 
-    const QWebElement clearData = createLinkItem(i18n("Clear Private Data"),
-                                  QL1S("about:history/clear"),
-                                  QL1S("edit-clear"),
-                                  KIconLoader::Toolbar);
-    m_root.document().findFirst(QL1S("#actions")).appendInside(clearData);
+    const QWebElement clearHistory = createLinkItem(i18n("Clear History"),
+                                     QL1S("about:history/clear"),
+                                     QL1S("edit-clear"),
+                                     KIconLoader::Toolbar);
+    m_root.document().findFirst(QL1S("#actions")).appendInside(clearHistory);
 
     HistoryTreeModel *model = rApp->historyManager()->historyTreeModel();
 
@@ -410,8 +353,8 @@ void NewTabPage::historyPage()
     }
 
     int i = 0;
-    QString faviconsDir = KStandardDirs::locateLocal("cache" , "favicons/" , true);
-    QString icon = QL1S("file://") + KGlobal::dirs()->findResource("icon", "oxygen/16x16/mimetypes/text-html.png");
+    const int maxTextSize = 103;
+    const int truncateSize = 100;
     do
     {
         QModelIndex index = model->index(i, 0, QModelIndex());
@@ -420,26 +363,32 @@ void NewTabPage::historyPage()
             m_root.appendInside(markup(QL1S("h3")));
             m_root.lastChild().setPlainText(index.data().toString());
 
+            m_root.appendInside(markup(QL1S(".folder")));
+            QWebElement little = m_root.lastChild();
             for (int j = 0; j < model->rowCount(index); ++j)
             {
                 QModelIndex son = model->index(j, 0, index);
                 KUrl u = son.data(HistoryModel::UrlStringRole).toUrl();
 
-                QString b = faviconsDir + u.host() + QL1S(".png");
-                if (QFile::exists(b))
-                    icon = QL1S("file://") + b;
+                little.appendInside(son.data(HistoryModel::DateTimeRole).toDateTime().toString("hh:mm"));
+                little.appendInside(QL1S("&nbsp;&nbsp;"));
+                little.appendInside(markup(QL1S("img")));
+                little.lastChild().setAttribute(QL1S("src"), rApp->iconManager()->iconPathForUrl(u));
+                little.lastChild().setAttribute(QL1S("width"), QL1S("16"));
+                little.lastChild().setAttribute(QL1S("height"), QL1S("16"));
+                little.appendInside(QL1S("&nbsp;&nbsp;"));
+                little.appendInside(markup(QL1S("a")));
+                little.lastChild().setAttribute(QL1S("href") , u.url());
 
-                m_root.appendInside(son.data(HistoryModel::DateTimeRole).toDateTime().toString("hh:mm"));
-                m_root.appendInside(QL1S("  "));
-                m_root.appendInside(markup(QL1S("img")));
-                m_root.lastChild().setAttribute(QL1S("src"), icon);
-                m_root.lastChild().setAttribute(QL1S("width"), QL1S("16"));
-                m_root.lastChild().setAttribute(QL1S("height"), QL1S("16"));
-                m_root.appendInside(QL1S(" "));
-                m_root.appendInside(markup(QL1S("a")));
-                m_root.lastChild().setAttribute(QL1S("href") , u.url());
-                m_root.lastChild().appendInside(son.data().toString());
-                m_root.appendInside(QL1S("<br />"));
+                QString shownUrl = son.data().toString();
+                if (shownUrl.length() > maxTextSize)
+                {
+                    shownUrl.truncate(truncateSize);
+                    shownUrl += QL1S("...");
+                }
+                little.lastChild().appendInside(shownUrl);
+
+                little.appendInside(QL1S("<br />"));
             }
         }
         i++;
@@ -458,7 +407,7 @@ void NewTabPage::bookmarksPage()
                                       KIconLoader::Toolbar);
     m_root.document().findFirst(QL1S("#actions")).appendInside(editBookmarks);
 
-    KBookmarkGroup bookGroup = rApp->bookmarkProvider()->rootGroup();
+    KBookmarkGroup bookGroup = rApp->bookmarkManager()->rootGroup();
     if (bookGroup.isNull())
     {
         m_root.addClass(QL1S("empty"));
@@ -475,6 +424,334 @@ void NewTabPage::bookmarksPage()
 }
 
 
+void NewTabPage::closedTabsPage()
+{
+    m_root.addClass(QL1S("closedTabs"));
+
+    QList<TabHistory> links = rApp->mainWindow()->mainView()->recentlyClosedTabs();
+
+    kDebug() << "CLOSED TABS: " << links.count();
+    if (links.isEmpty())
+    {
+        m_root.addClass(QL1S("empty"));
+        m_root.setPlainText(i18n("There are no recently closed tabs"));
+        return;
+    }
+
+    for (int i = 0; i < links.count(); ++i)
+    {
+        TabHistory item = links.at(i);
+        kDebug() << "URL " << i << " : " << item.url;
+        QWebElement prev;
+
+        if (item.url.isEmpty())
+            continue;
+
+        prev = closedTabPreview(i, item.url, item.title);
+
+        prev.setAttribute(QL1S("id"),  QL1S("preview") + QVariant(i).toString());
+        hideControls(prev);
+        m_root.appendInside(prev);
+    }
+}
+
+
+void NewTabPage::downloadsPage()
+{
+    m_root.addClass(QL1S("downloads"));
+
+    const QWebElement clearDownloads = createLinkItem(i18n("Clear Downloads"),
+                                       QL1S("about:downloads/clear"),
+                                       QL1S("edit-clear"),
+                                       KIconLoader::Toolbar);
+    m_root.document().findFirst(QL1S("#actions")).appendInside(clearDownloads);
+
+    DownloadList list = rApp->downloadManager()->downloads();
+
+    if (list.isEmpty())
+    {
+        m_root.addClass(QL1S("empty"));
+        m_root.setPlainText(i18n("There are no recently downloaded files to show"));
+        return;
+    }
+
+    Q_FOREACH(DownloadItem * item, list)
+    {
+        m_root.prependInside(markup(QL1S("div")));
+
+        QWebElement div = m_root.firstChild();
+        div.addClass(QL1S("download"));
+
+        KUrl u = KUrl(item->destinationUrl());
+        QString fName = u.fileName();
+        QString dir = u.directory();
+        QString file = dir + QL1C('/') + fName;
+
+        KIconLoader *loader = KIconLoader::global();
+        QString iconPath = QL1S("file://") + loader->iconPath(KMimeType::iconNameForUrl(u), KIconLoader::Desktop);
+
+        div.appendInside(markup(QL1S("img")));
+        div.lastChild().setAttribute(QL1S("src"), iconPath);
+
+        div.appendInside(QL1S("<strong>") + fName +  QL1S("</strong>"));
+        div.appendInside(QL1S(" - "));
+        QString date = KGlobal::locale()->formatDateTime(item->dateTime(), KLocale::FancyLongDate);
+        div.appendInside(QL1S("<em>") + date +  QL1S("</em>"));
+        div.appendInside(QL1S("<br />"));
+
+        div.appendInside(QL1S("<a href=") + item->originUrl() +  QL1C('>') + item->originUrl() +  QL1S("</a>"));
+        div.appendInside(QL1S("<br />"));
+
+        if (QFile::exists(file))
+        {
+            div.appendInside(markup(QL1S("a")));
+            div.lastChild().setAttribute(QL1S("href"), QL1S("file://") + dir);
+            div.lastChild().setPlainText(i18n("Open directory"));
+
+            div.appendInside(QL1S(" - "));
+            div.appendInside(markup(QL1S("a")));
+            div.lastChild().setAttribute(QL1S("href"), QL1S("file://") + file);
+            div.lastChild().setPlainText(i18n("Open file"));
+        }
+        else
+        {
+            div.appendInside(QL1S("<em>") + QL1S("Removed") +  QL1S("</em>"));
+        }
+    }
+}
+
+
+void NewTabPage::tabsPage()
+{
+    m_root.addClass(QL1S("tabs"));
+
+    int wins = 0;
+    Q_FOREACH(const QWeakPointer<MainWindow> &wPointer, rApp->mainWindowList())
+    {
+        m_root.appendInside(markup(QL1S("h3")));
+        m_root.lastChild().setPlainText("Window");
+
+        MainWindow *w = wPointer.data();
+
+        const int tabCount = w->mainView()->count();
+        for (int i = 0; i < tabCount; ++i)
+        {
+            KUrl url = w->mainView()->webTab(i)->url();
+
+            if (!WebSnap::existsImage(url))
+            {
+                kDebug() << "image doesn't exist for url: " << url;
+                QPixmap preview = WebSnap::renderPagePreview(*w->mainView()->webTab(i)->page());
+                QString path = WebSnap::imagePathFromUrl(url.url());
+                preview.save(path);
+            }
+            QString name = w->mainView()->webTab(i)->view()->title();
+            QWebElement prev;
+
+            prev = tabPreview(wins, i, url, name);
+
+            m_root.appendInside(prev);
+        }
+
+        wins++;
+    }
+}
+
+
+// ----------------------------------------------------------------------------
+// LOW-LEVEL FUNCTIONS
+
+
+QWebElement NewTabPage::emptyPreview(int index)
+{
+    QWebElement prev = markup(QL1S(".thumbnail"));
+
+    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") ,
+            QL1S("file:///") + KIconLoader::global()->iconPath("insert-image", KIconLoader::Desktop));
+    prev.findFirst(QL1S("span a")).setPlainText(i18n("Set a Preview..."));
+    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"),
+                                           QL1S("about:preview/modify/") + QVariant(index).toString());
+
+    setupPreview(prev, index);
+
+    return prev;
+}
+
+
+// NOTE: comment this out WITHOUT really deleting. May be of inspiration...
+// QWebElement NewTabPage::loadingPreview(int index, const KUrl &url)
+// {
+//     QWebElement prev = markup(QL1S(".thumbnail"));
+//
+//     prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src"),
+//             QL1S("file:///") + KStandardDirs::locate("appdata", "pics/busywidget.gif"));
+//     prev.findFirst(QL1S("span a")).setPlainText(i18n("Loading Preview..."));
+//     prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), url.toMimeDataString());
+//
+//     setupPreview(prev, index);
+//     showControls(prev);
+//
+//     // NOTE: we need the page frame for two reasons
+//     // 1) to link to the WebPage calling the snapFinished slot
+//     // 2) to "auto-destroy" snaps on tab closing :)
+//     QWebFrame *frame = qobject_cast<QWebFrame *>(parent());
+//     WebSnap *snap = new WebSnap(url, frame);
+//     connect(snap, SIGNAL(snapDone(bool)), frame->page(), SLOT(updateImage(bool)), Qt::UniqueConnection);
+//     return prev;
+// }
+//
+//
+// void NewTabPage::updateThumbs()
+// {
+//     // Update page, but only if open
+//     if (m_root.document().findAll(QL1S("#rekonq-newtabpage")).count() == 0)
+//         return;
+//     if (m_root.findAll(QL1S(".favorites")).count() == 0 && m_root.findAll(QL1S(".closedTabs")).count() == 0)
+//         return;
+//
+//     QStringList urls = ReKonfig::previewUrls();
+//     QStringList names = ReKonfig::previewNames();
+//
+//     for (int i = 0; i < urls.count(); i++)
+//     {
+//         KUrl url = KUrl(urls.at(i));
+//         QString title = names.at(i);
+//
+//         if (WebSnap::existsImage(url))
+//         {
+//             QWebElement prev = m_root.findFirst(QL1S("#preview") + QVariant(i).toString());
+//             if (KUrl(prev.findFirst("a").attribute(QL1S("href"))) == url)
+//             {
+//                 QWebElement newPrev = validPreview(i, url, title);
+//
+//                 if (m_root.findAll(QL1S(".closedTabs")).count() != 0)
+//                     hideControls(newPrev);
+//
+//                 prev.replace(newPrev);
+//             }
+//         }
+//     }
+// }
+
+
+QWebElement NewTabPage::validPreview(int index, const KUrl &url, const QString &title)
+{
+    QWebElement prev = markup(QL1S(".thumbnail"));
+
+    QString previewPath = WebSnap::existsImage(url)
+                          ? QL1S("file://") + WebSnap::imagePathFromUrl(url)
+                          : rApp->iconManager()->iconPathForUrl(url)
+                          ;
+
+    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") , previewPath);
+    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), url.toMimeDataString());
+    prev.findFirst(QL1S("span a")).setAttribute(QL1S("href"), url.toMimeDataString());
+    prev.findFirst(QL1S("span a")).setPlainText(checkTitle(title));
+
+    setupPreview(prev, index);
+    showControls(prev);
+    return prev;
+}
+
+
+QWebElement NewTabPage::tabPreview(int winIndex, int tabIndex, const KUrl &url, const QString &title)
+{
+    QWebElement prev = markup(QL1S(".thumbnail"));
+    QString previewPath = QL1S("file://") + WebSnap::imagePathFromUrl(url);
+
+    QString href = QL1S("about:tabs/show?win=") + QString::number(winIndex) + QL1S("&tab=") + QString::number(tabIndex);
+
+    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") , previewPath);
+    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), href);
+    prev.findFirst(QL1S("span a")).setAttribute(QL1S("href"), href);
+    prev.findFirst(QL1S("span a")).setPlainText(checkTitle(title));
+
+    setupTabPreview(prev, winIndex, tabIndex);
+    prev.findFirst(QL1S(".remove")).setStyleProperty(QL1S("visibility"), QL1S("visible"));
+    prev.findFirst(QL1S(".modify")).setStyleProperty(QL1S("visibility"), QL1S("hidden"));
+    return prev;
+}
+
+
+QWebElement NewTabPage::closedTabPreview(int index, const KUrl &url, const QString &title)
+{
+    QWebElement prev = markup(QL1S(".thumbnail"));
+
+    QString previewPath = WebSnap::existsImage(url)
+                          ? QL1S("file://") + WebSnap::imagePathFromUrl(url)
+                          : rApp->iconManager()->iconPathForUrl(url)
+                          ;
+
+    QString href = QL1S("about:closedTabs/restore?tab=") + QString::number(index);
+
+    prev.findFirst(QL1S(".preview img")).setAttribute(QL1S("src") , previewPath);
+    prev.findFirst(QL1S("a")).setAttribute(QL1S("href"), href);
+    prev.findFirst(QL1S("span a")).setAttribute(QL1S("href"), href);
+    prev.findFirst(QL1S("span a")).setPlainText(checkTitle(title));
+
+    setupPreview(prev, index);
+    showControls(prev);
+    return prev;
+}
+
+
+void NewTabPage::hideControls(QWebElement e)
+{
+    e.findFirst(QL1S(".remove")).setStyleProperty(QL1S("visibility"), QL1S("hidden"));
+    e.findFirst(QL1S(".modify")).setStyleProperty(QL1S("visibility"), QL1S("hidden"));
+}
+
+
+void NewTabPage::showControls(QWebElement e)
+{
+    e.findFirst(QL1S(".remove")).setStyleProperty(QL1S("visibility"), QL1S("visible"));
+    e.findFirst(QL1S(".modify")).setStyleProperty(QL1S("visibility"), QL1S("visible"));
+}
+
+
+void NewTabPage::setupPreview(QWebElement e, int index)
+{
+    e.findFirst(QL1S(".remove img")).setAttribute(QL1S("src"), QL1S("file:///") + KIconLoader::global()->iconPath("edit-delete", KIconLoader::DefaultState));
+    e.findFirst(QL1S(".remove")).setAttribute(QL1S("title"), QL1S("Remove favorite"));
+    e.findFirst(QL1S(".modify img")).setAttribute(QL1S("src"), QL1S("file:///") + KIconLoader::global()->iconPath("insert-image", KIconLoader::DefaultState));
+    e.findFirst(QL1S(".modify")).setAttribute(QL1S("title"), QL1S("Set new favorite"));
+
+    e.findFirst(QL1S(".modify")).setAttribute(QL1S("href"), QL1S("about:preview/modify/") + QVariant(index).toString());
+    e.findFirst(QL1S(".remove")).setAttribute(QL1S("href"), QL1S("about:preview/remove/") + QVariant(index).toString());
+
+    e.setAttribute(QL1S("id"), QL1S("preview") + QVariant(index).toString());
+}
+
+
+void NewTabPage::setupTabPreview(QWebElement e, int winIndex, int tabIndex)
+{
+    e.findFirst(QL1S(".remove img")).setAttribute(QL1S("src"), QL1S("file:///") + KIconLoader::global()->iconPath("edit-delete", KIconLoader::DefaultState));
+    e.findFirst(QL1S(".remove")).setAttribute(QL1S("title"), QL1S("Close Tab"));
+
+    QString href = QL1S("about:tabs/remove?win=") + QString::number(winIndex) + QL1S("&tab=") + QString::number(tabIndex);
+    e.findFirst(QL1S(".remove")).setAttribute(QL1S("href"), href);
+
+    e.setAttribute(QL1S("id"), QL1S("win") + QString::number(winIndex) + QL1S("tab") + QString::number(tabIndex));
+}
+
+
+void NewTabPage::removePreview(int index)
+{
+    QStringList names = ReKonfig::previewNames();
+    QStringList urls = ReKonfig::previewUrls();
+
+    urls.removeAt(index);
+    names.removeAt(index);
+
+    ReKonfig::setPreviewNames(names);
+    ReKonfig::setPreviewUrls(urls);
+
+    generate(KUrl("about:favorites"));
+
+    ReKonfig::self()->writeConfig();
+}
+
+
 void NewTabPage::createBookItem(const KBookmark &bookmark, QWebElement parent)
 {
     QString cacheDir = QL1S("file://") + KStandardDirs::locateLocal("cache" , "" , true);
@@ -485,10 +762,10 @@ void NewTabPage::createBookItem(const KBookmark &bookmark, QWebElement parent)
         KBookmark bm = group.first();
         parent.appendInside(markup(QL1S("h3")));
         parent.lastChild().setPlainText(group.fullText());
-        parent.appendInside(markup(QL1S(".bookfolder")));
+        parent.appendInside(markup(QL1S(".folder")));
         while (!bm.isNull())
         {
-            createBookItem(bm, parent.lastChild()); // it is .bookfolder
+            createBookItem(bm, parent.lastChild()); // it is .folder
             bm = group.next(bm);
         }
     }
@@ -515,38 +792,6 @@ void NewTabPage::createBookItem(const KBookmark &bookmark, QWebElement parent)
 }
 
 
-void NewTabPage::closedTabsPage()
-{
-    m_root.addClass(QL1S("closedTabs"));
-
-    QList<TabHistory> links = rApp->mainWindow()->mainView()->recentlyClosedTabs();
-
-    if (links.isEmpty())
-    {
-        m_root.addClass(QL1S("empty"));
-        m_root.setPlainText(i18n("There are no recently closed tabs"));
-        return;
-    }
-
-    for (int i = 0; i < links.count(); ++i)
-    {
-        TabHistory item = links.at(i);
-        QWebElement prev;
-
-        if (item.url.isEmpty())
-            continue;
-
-        prev = WebSnap::existsImage(KUrl(item.url))
-               ? validPreview(i, item.url, item.title)
-               : loadingPreview(i, item.url);
-
-        prev.setAttribute(QL1S("id"),  QL1S("preview") + QVariant(i).toString());
-        hideControls(prev);
-        m_root.appendInside(prev);
-    }
-}
-
-
 QString NewTabPage::checkTitle(const QString &title)
 {
     QString t(title);
@@ -559,64 +804,6 @@ QString NewTabPage::checkTitle(const QString &title)
 }
 
 
-void NewTabPage::downloadsPage()
-{
-    m_root.addClass(QL1S("downloads"));
-
-    const QWebElement clearData = createLinkItem(i18n("Clear Private Data"),
-                                  QL1S("about:downloads/clear"),
-                                  QL1S("edit-clear"),
-                                  KIconLoader::Toolbar);
-    m_root.document().findFirst(QL1S("#actions")).appendInside(clearData);
-
-    DownloadList list = rApp->downloadManager()->downloads();
-
-    if (list.isEmpty())
-    {
-        m_root.addClass(QL1S("empty"));
-        m_root.setPlainText(i18n("There are no recently downloaded files to show"));
-        return;
-    }
-
-    foreach(DownloadItem * item, list)
-    {
-        m_root.prependInside(markup(QL1S("div")));
-
-        QWebElement div = m_root.firstChild();
-        div.addClass(QL1S("download"));
-
-        KUrl u = KUrl(item->destinationUrl());
-        QString fName = u.fileName();
-        QString dir = QL1S("file://") + u.directory();
-        QString file = dir +  QL1C('/') + fName;
-
-        KIconLoader *loader = KIconLoader::global();
-        QString iconPath = QL1S("file://") + loader->iconPath(KMimeType::iconNameForUrl(u), KIconLoader::Desktop);
-
-        div.appendInside(markup(QL1S("img")));
-        div.lastChild().setAttribute(QL1S("src"), iconPath);
-
-        div.appendInside(QL1S("<strong>") + fName +  QL1S("</strong>"));
-        div.appendInside(QL1S(" - "));
-        QString date = KGlobal::locale()->formatDateTime(item->dateTime(), KLocale::FancyLongDate);
-        div.appendInside(QL1S("<em>") + date +  QL1S("</em>"));
-        div.appendInside(QL1S("<br />"));
-
-        div.appendInside(QL1S("<a href=") + item->originUrl() +  QL1C('>') + item->originUrl() +  QL1S("</a>"));
-        div.appendInside(QL1S("<br />"));
-
-        div.appendInside(markup(QL1S("a")));
-        div.lastChild().setAttribute(QL1S("href"), dir);
-        div.lastChild().setPlainText(i18n("Open directory"));
-
-        div.appendInside(QL1S(" - "));
-        div.appendInside(markup(QL1S("a")));
-        div.lastChild().setAttribute(QL1S("href"), file);
-        div.lastChild().setPlainText(i18n("Open file"));
-    }
-}
-
-
 QWebElement NewTabPage::createLinkItem(const QString &title, const QString &urlString, const QString &iconPath, int groupOrSize) const
 {
     const KIconLoader * const loader = KIconLoader::global();
@@ -628,6 +815,7 @@ QWebElement NewTabPage::createLinkItem(const QString &title, const QString &urlS
     return nav;
 }
 
+
 void NewTabPage::updateWindowIcon()
 {
     int currentIndex = rApp->mainWindow()->mainView()->currentIndex();
