@@ -51,18 +51,24 @@
 #define QL1S(x)  QLatin1String(x)
 #define QL1C(x)  QLatin1Char(x)
 
-
+#ifndef ASSERT_NOT_REACHED
+#  ifndef QT_NO_DEBUG
+#    define ASSERT_NOT_REACHED(msg) qt_assert(#msg,__FILE__,__LINE__); kDebug() << #msg
+#  else
+#    define ASSERT_NOT_REACHED(msg) kDebug() << #msg
+#  endif
+#endif //ASSERT_NOT_REACHED
 
 // ----------------------------------------------------------------------------------------------------
 // ENUMS
 
 namespace Rekonq
 {
+
 /**
 * @short notifying message status
 * Different message status
 */
-
 enum Notify
 {
     Success,    ///< url successfully (down)loaded
@@ -84,6 +90,18 @@ enum OpenType
     NewBackTab,     ///< open url in new tab in background
     NewWindow       ///< open url in new window
 };
+
+/**
+* @short data to be synced
+* Different data we can sync
+*/
+enum SyncData
+{
+    Bookmarks,
+    History,
+    Passwords
+};
+
 }
 
 
