@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2009 by Yoram Bar-Haim <<yoram.b at zend dot com>
 * Copyright (C) 2009-2011 by Lionel Chauvin <megabigbug@yahoo.fr>
 *
@@ -44,6 +44,64 @@
 #include <QtCore/QFile>
 
 
+// Only used internally
+bool readSessionDocument(QDomDocument & document, const QString & sessionFilePath)
+{
+    QFile sessionFile(sessionFilePath);
+
+    if (!sessionFile.exists())
+        return false;
+
+    if (!sessionFile.open(QFile::ReadOnly))
+    {
+        kDebug() << "Unable to open session file" << sessionFile.fileName();
+        return false;
+    }
+
+    if (!document.setContent(&sessionFile, false))
+    {
+        kDebug() << "Unable to parse session file" << sessionFile.fileName();
+        return false;
+    }
+
+    return true;
+}
+
+
+int loadViewTabs(MainView *mv, QDomElement & window, bool checkViewExists)
+{
+    int currentTab = 0;
+
+    for (unsigned int tabNo = 0; tabNo < window.elementsByTagName("tab").length(); tabNo++)
+    {
+        QDomElement tab = window.elementsByTagName("tab").at(tabNo).toElement();
+        if (tab.hasAttribute("currentTab"))
+            currentTab = tabNo;
+
+        WebView * view = 0;
+        if (tabNo == 0 && checkViewExists)
+            view = mv->webTab(0)->view();
+        else
+            view = mv->newWebTab()->view();
+
+        QDomCDATASection historySection = tab.firstChild().toCDATASection();
+        QByteArray history = QByteArray::fromBase64(historySection.data().toAscii());
+
+        QDataStream readingStream(&history, QIODevice::ReadOnly);
+        readingStream >> *(view->history());
+
+        // Get sure about urls and/or pdf are loaded
+        KUrl u = KUrl(tab.attribute("url"));
+        view->load(u);
+    }
+
+    return currentTab;
+}
+
+
+// ---------------------------------------------------------------------
+
+
 SessionManager::SessionManager(QObject *parent)
     : QObject(parent)
     , m_safe(true)
@@ -77,12 +135,19 @@ void SessionManager::saveSession()
     {
         MainView *mv = w.data()->mainView();
         QDomElement window = document.createElement("window");
+        int tabInserted = 0;
+
+        window.setAttribute("name", w.data()->objectName());
+
         for (signed int tabNo = 0; tabNo < mv->count(); tabNo++)
         {
+            KUrl u = mv->webTab(tabNo)->url();
+
+            tabInserted++;
             QDomElement tab = document.createElement("tab");
             tab.setAttribute("title", mv->webTab(tabNo)->view()->title()); // redundant, but needed for closedSites()
             // as there's not way to read out the historyData
-            tab.setAttribute("url", mv->webTab(tabNo)->url().url()); // Use WebTab's instead of WebView's url() to fix about links
+            tab.setAttribute("url", u.url());
             if (mv->tabBar()->currentIndex() == tabNo)
             {
                 tab.setAttribute("currentTab", 1);
@@ -95,7 +160,8 @@ void SessionManager::saveSession()
             tab.appendChild(historySection);
             window.appendChild(tab);
         }
-        session.appendChild(window);
+        if (tabInserted > 0)
+            session.appendChild(window);
     }
 
     QTextStream TextStream(&sessionFile);
@@ -109,52 +175,18 @@ void SessionManager::saveSession()
 
 bool SessionManager::restoreSessionFromScratch()
 {
-    QFile sessionFile(m_sessionFilePath);
-    if (!sessionFile.exists())
-        return false;
-    if (!sessionFile.open(QFile::ReadOnly))
-    {
-        kDebug() << "Unable to open session file" << sessionFile.fileName();
-        return false;
-    }
-
-    bool windowAlreadyOpen = (rApp->mainWindowList().count() == 0) ? false : true;
-    if (!windowAlreadyOpen)
-        rApp->newMainWindow(false);
-
     QDomDocument document("session");
-    if (!document.setContent(&sessionFile, false))
-    {
-        kDebug() << "Unable to parse session file" << sessionFile.fileName();
+
+    if (!readSessionDocument(document, m_sessionFilePath))
         return false;
-    }
 
     for (unsigned int winNo = 0; winNo < document.elementsByTagName("window").length(); winNo++)
     {
         QDomElement window = document.elementsByTagName("window").at(winNo).toElement();
-        int currentTab = 0;
 
-        MainView *mv = rApp->mainWindowList().at(0).data()->mainView(); //last mainwindow created will be first one in mainwindow list
+        MainView *mv = rApp->newMainWindow(false)->mainView();
 
-        for (unsigned int tabNo = 0; tabNo < window.elementsByTagName("tab").length(); tabNo++)
-        {
-            QDomElement tab = window.elementsByTagName("tab").at(tabNo).toElement();
-            if (tab.hasAttribute("currentTab"))
-                currentTab = tabNo;
-
-            WebView *view = mv->newWebTab()->view();
-
-            QDomCDATASection historySection = tab.firstChild().toCDATASection();
-            QByteArray history = QByteArray::fromBase64(historySection.data().toAscii());
-
-            QDataStream readingStream(&history, QIODevice::ReadOnly);
-            readingStream >> *(view->history());
-
-            // Get sure about urls are loaded
-            KUrl u = KUrl(tab.attribute("url"));
-            if (u.protocol() == QL1S("about"))
-                view->load(u);
-        }
+        int currentTab = loadViewTabs(mv, window, false);
 
         mv->tabBar()->setCurrentIndex(currentTab);
     }
@@ -165,52 +197,19 @@ bool SessionManager::restoreSessionFromScratch()
 
 void SessionManager::restoreCrashedSession()
 {
-    QFile sessionFile(m_sessionFilePath);
-    if (!sessionFile.exists())
-    {
-        kDebug() << "Unable to find session file" << sessionFile.fileName();
-        return;
-    }
-
-    if (!sessionFile.open(QFile::ReadOnly))
-    {
-        kDebug() << "Unable to open session file" << sessionFile.fileName();
-        return;
-    }
-
     QDomDocument document("session");
-    if (!document.setContent(&sessionFile, false))
-    {
-        kDebug() << "Unable to parse session file" << sessionFile.fileName();
+
+    if (!readSessionDocument(document, m_sessionFilePath))
         return;
-    }
 
     for (unsigned int winNo = 0; winNo < document.elementsByTagName("window").length(); winNo++)
     {
         QDomElement window = document.elementsByTagName("window").at(winNo).toElement();
-        int currentTab = 0;
 
         MainView *mv = (winNo == 0) ? rApp->mainWindow()->mainView() : rApp->newMainWindow()->mainView();
 
-        for (unsigned int tabNo = 0; tabNo < window.elementsByTagName("tab").length(); tabNo++)
-        {
-            QDomElement tab = window.elementsByTagName("tab").at(tabNo).toElement();
-            if (tab.hasAttribute("currentTab"))
-                currentTab = tabNo;
+        int currentTab = loadViewTabs(mv, window, true);
 
-            WebView *view = (tabNo == 0) ? mv->webTab(0)->view() : mv->newWebTab()->view();
-
-            QDomCDATASection historySection = tab.firstChild().toCDATASection();
-            QByteArray history = QByteArray::fromBase64(historySection.data().toAscii());
-
-            QDataStream readingStream(&history, QIODevice::ReadOnly);
-            readingStream >> *(view->history());
-
-            // Get sure about urls are loaded
-            KUrl u = KUrl(tab.attribute("url"));
-            if (u.protocol() == QL1S("about"))
-                view->load(u);
-        }
         mv->tabBar()->setCurrentIndex(currentTab);
     }
 
@@ -220,54 +219,21 @@ void SessionManager::restoreCrashedSession()
 
 int SessionManager::restoreSavedSession()
 {
-    QFile sessionFile(m_sessionFilePath);
-    if (!sessionFile.exists())
-    {
-        kDebug() << "Unable to find session file" << sessionFile.fileName();
-        return 0;
-    }
-
-    if (!sessionFile.open(QFile::ReadOnly))
-    {
-        kDebug() << "Unable to open session file" << sessionFile.fileName();
-        return 0;
-    }
-
     QDomDocument document("session");
-    if (!document.setContent(&sessionFile, false))
-    {
-        kDebug() << "Unable to parse session file" << sessionFile.fileName();
+
+    if (!readSessionDocument(document, m_sessionFilePath))
         return 0;
-    }
 
     unsigned int winNo;
 
     for (winNo = 0; winNo < document.elementsByTagName("window").length(); winNo++)
     {
         QDomElement window = document.elementsByTagName("window").at(winNo).toElement();
-        int currentTab = 0;
 
         MainView *mv = rApp->newMainWindow()->mainView();
 
-        for (unsigned int tabNo = 0; tabNo < window.elementsByTagName("tab").length(); tabNo++)
-        {
-            QDomElement tab = window.elementsByTagName("tab").at(tabNo).toElement();
-            if (tab.hasAttribute("currentTab"))
-                currentTab = tabNo;
+        int currentTab = loadViewTabs(mv, window, true);
 
-            WebView *view = (tabNo == 0) ? mv->webTab(0)->view() : mv->newWebTab()->view();
-
-            QDomCDATASection historySection = tab.firstChild().toCDATASection();
-            QByteArray history = QByteArray::fromBase64(historySection.data().toAscii());
-
-            QDataStream readingStream(&history, QIODevice::ReadOnly);
-            readingStream >> *(view->history());
-
-            // Get sure about urls are loaded
-            KUrl u = KUrl(tab.attribute("url"));
-            if (u.protocol() == QL1S("about"))
-                view->load(u);
-        }
         mv->tabBar()->setCurrentIndex(currentTab);
     }
 
@@ -275,25 +241,42 @@ int SessionManager::restoreSavedSession()
 }
 
 
+bool SessionManager::restoreMainWindow(MainWindow* window)
+{
+    QDomDocument document("session");
+
+    if (!readSessionDocument(document, m_sessionFilePath))
+        return false;
+
+    unsigned int winNo;
+
+    for (winNo = 0; winNo < document.elementsByTagName("window").length(); winNo++)
+    {
+        QDomElement savedWindowElement = document.elementsByTagName("window").at(winNo).toElement();
+
+        if (window->objectName() != savedWindowElement.attribute("name", ""))
+            continue;
+
+        MainView *mv = window->mainView();
+
+        int currentTab = loadViewTabs(mv, savedWindowElement, false);
+
+        mv->tabBar()->setCurrentIndex(currentTab);
+
+        return true;
+    }
+
+    return false;
+}
+
+
 QList<TabHistory> SessionManager::closedSites()
 {
     QList<TabHistory> list;
-
-    QFile sessionFile(m_sessionFilePath);
-    if (!sessionFile.exists())
-        return list;
-    if (!sessionFile.open(QFile::ReadOnly))
-    {
-        kDebug() << "Unable to open session file" << sessionFile.fileName();
-        return list;
-    }
-
     QDomDocument document("session");
-    if (!document.setContent(&sessionFile, false))
-    {
-        kDebug() << "Unable to parse session file" << sessionFile.fileName();
+
+    if (!readSessionDocument(document, m_sessionFilePath))
         return list;
-    }
 
     for (unsigned int tabNo = 0; tabNo < document.elementsByTagName("tab").length(); tabNo++)
     {
