@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2010-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2010-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -38,10 +38,12 @@
 
 //KDE Includes
 #include <kstandarddirs.h>
+#include <KUrlRequester>
+
 
 GeneralWidget::GeneralWidget(QWidget *parent)
-        : QWidget(parent)
-        , _changed(false)
+    : QWidget(parent)
+    , _changed(false)
 {
     setupUi(this);
 
@@ -52,11 +54,33 @@ GeneralWidget::GeneralWidget(QWidget *parent)
     connect(kcfg_useNewTabPage, SIGNAL(toggled(bool)), this, SLOT(disableHomeSettings(bool)));
 
     checkKGetPresence();
+
+    KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig("kioslaverc", KConfig::NoGlobals), QString());
+    doNotTrackCheckBox->setChecked(cg.readEntry("DoNotTrack", false));
+
+    connect(doNotTrackCheckBox, SIGNAL(clicked()), this, SLOT(hasChanged()));
+    connect(kcfg_homePage, SIGNAL(editingFinished()), this, SLOT(fixHomePageURL()));
+
+    kcfg_downloadPath->setMode(KFile::Directory);
+
+    askDownloadYes->setChecked(ReKonfig::askDownloadPath());
+    askDownloadNo->setChecked(!ReKonfig::askDownloadPath());
+
+    kcfg_downloadPath->setEnabled(!ReKonfig::askDownloadPath());
+    connect(askDownloadNo, SIGNAL(toggled(bool)), kcfg_downloadPath, SLOT(setEnabled(bool)));
+    connect(askDownloadNo, SIGNAL(toggled(bool)), this, SLOT(hasChanged()));
 }
 
 
 void GeneralWidget::save()
 {
+    ReKonfig::setAskDownloadPath(askDownloadYes->isChecked());
+
+    KConfigGroup cg = KConfigGroup(KSharedConfig::openConfig("kioslaverc", KConfig::NoGlobals), QString());
+    cg.writeEntry("DoNotTrack", doNotTrackCheckBox->isChecked());
+    cg.sync();
+
+    _changed = false;
 }
 
 
@@ -68,6 +92,8 @@ bool GeneralWidget::changed()
 
 void GeneralWidget::hasChanged()
 {
+    _changed = true;
+    emit changed(true);
 }
 
 
@@ -88,6 +114,7 @@ void GeneralWidget::disableHomeSettings(bool b)
     setHomeToCurrentPageButton->setEnabled(!b);
 }
 
+
 void GeneralWidget::checkKGetPresence()
 {
     if (KStandardDirs::findExe("kget").isNull())
@@ -103,3 +130,10 @@ void GeneralWidget::checkKGetPresence()
         kcfg_kgetList->setDisabled(false);
     }
 }
+
+
+void GeneralWidget::fixHomePageURL()
+{
+    QString fixedURL = QUrl::fromUserInput(kcfg_homePage->text()).toString();
+    kcfg_homePage->setText(fixedURL);
+}
