@@ -45,11 +45,12 @@ public:
     void save();
     bool changed();
 
-signals:
+Q_SIGNALS:
     void changed(bool);
 
-private slots:
+private Q_SLOTS:
     void hasChanged();
+    void updateJavascriptSettings(bool);
 
 private:
     void setWebSettingsToolTips();
