@@ -2,7 +2,7 @@
 *
 * This file is a part of the rekonq project
 *
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -73,9 +73,9 @@ void CompletionWidget::insertItems(const UrlSearchList &list, const QString& tex
         ListItem *suggestion = ListItemFactory::create(item, text, this);
         suggestion->setBackgroundRole(offset % 2 ? QPalette::AlternateBase : QPalette::Base);
         connect(suggestion,
-                SIGNAL(itemClicked(ListItem *, Qt::MouseButton, Qt::KeyboardModifiers)),
+                SIGNAL(itemClicked(ListItem*,Qt::MouseButton,Qt::KeyboardModifiers)),
                 this,
-                SLOT(itemChosen(ListItem *, Qt::MouseButton, Qt::KeyboardModifiers)));
+                SLOT(itemChosen(ListItem*,Qt::MouseButton,Qt::KeyboardModifiers)));
         connect(suggestion, SIGNAL(updateList()), this, SLOT(updateList()));
         connect(this, SIGNAL(nextItemSubChoice()), suggestion, SLOT(nextItemSubChoice()));
 
@@ -278,7 +278,7 @@ bool CompletionWidget::eventFilter(QObject *obj, QEvent *ev)
 
                     if (!append.isEmpty())
                     {
-                        QUrl url(QL1S("http://www.") + w->text());
+                        QUrl url(QL1S("http://") + w->text());
                         QString host = url.host();
                         if (!host.endsWith(append, Qt::CaseInsensitive))
                         {
@@ -384,7 +384,8 @@ void CompletionWidget::suggestUrls(const QString &text)
     }
 
     UrlResolver *res = new UrlResolver(text);
-    connect(res, SIGNAL(suggestionsReady(const UrlSearchList &, const QString &)), this, SLOT(updateSearchList(const UrlSearchList &, const QString &)));
+    connect(res, SIGNAL(suggestionsReady(UrlSearchList,QString)),
+            this, SLOT(updateSearchList(UrlSearchList,QString)));
     _resList = res->orderedSearchItems();
 
     // NOTE: It's important to call this AFTER orderedSearchItems() to let everything work
