@@ -60,6 +60,7 @@
 #include <QtGui/QPalette>
 #include <QtGui/QVBoxLayout>
 #include <QClipboard>
+#include <QTimer>
 
 
 
@@ -133,8 +134,7 @@ UrlBar::UrlBar(QWidget *parent)
     connect(_tab->view(), SIGNAL(iconChanged()), this, SLOT(refreshFavicon()));
 
     // search icon
-    connect(rApp->opensearchManager(), SIGNAL(openSearchEngineAdded(QString,QString,QString)),
-            this, SLOT(updateRightIcons()));
+    connect(rApp->opensearchManager(), SIGNAL(openSearchEngineAdded(QString)), this, SLOT(updateRightIcons()));
 
     // bookmark icon
     connect(rApp->bookmarkManager(), SIGNAL(bookmarksUpdated()), this, SLOT(updateRightIcons()));
