@@ -35,11 +35,7 @@
 
 // KDE Includes
 #include <KBookmark>
-#include <KUriFilter>
-#include <KCompletion>
 #include <KService>
-#include <KConfig>
-#include <KConfigGroup>
 #include <KProtocolInfo>
 
 // Qt Includes
@@ -163,7 +159,8 @@ UrlSearchList UrlResolver::orderLists()
     bool webSearchFirst = false;
     // Browse & Search results
     UrlSearchList browseSearch;
-    if (_browseRegexp.indexIn(_typedString) != -1)
+    QString lowerTypedString = _typedString.toLower();
+    if (_browseRegexp.indexIn(lowerTypedString) != -1)
     {
         webSearchFirst = true;
         browseSearch << _webSearches;
@@ -255,8 +252,16 @@ void UrlResolver::computeQurlFromUserInput()
     QUrl urlFromUserInput = QUrl::fromUserInput(url);
     if (urlFromUserInput.isValid())
     {
+        // ensure http(s) hosts are lower cases
+        if (urlFromUserInput.scheme().startsWith("http"))
+        {
+            QString hst = urlFromUserInput.host();
+            urlFromUserInput.setHost(hst.toLower());
+        }
+        
+        QString urlString = urlFromUserInput.toString();
         QString gTitle = i18nc("Browse a website", "Browse");
-        UrlSearchItem gItem(UrlSearchItem::Browse, urlFromUserInput.toString(), gTitle);
+        UrlSearchItem gItem(UrlSearchItem::Browse, urlString, gTitle);
         _qurlFromUserInput << gItem;
     }
 }
