@@ -4,6 +4,7 @@
 *
 * Copyright (C) 2009 by Fredy Yanardi <fyanardi@gmail.com>
 * Copyright (C) 2010-2011 by  Lionel Chauvin <megabigbug@yahoo.fr>
+* Copyright (C) 2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -28,15 +29,24 @@
 #ifndef WEBSHORTCUTWIDGET_H
 #define WEBSHORTCUTWIDGET_H
 
-#include <QMenu>
+
+// Rekonq Includes
+#include "rekonq_defines.h"
+
+// KDE Includes
 #include <KUrl>
 #include <KService>
 
+// Qt Includes
+#include <QMenu>
+
+// Forward Declarations
 class QLabel;
 class QLineEdit;
 class QPushButton;
 
-class WebShortcutWidget : public QMenu
+
+class REKONQ_TESTS_EXPORT WebShortcutWidget : public QMenu
 {
     Q_OBJECT
 public:
