@@ -3,7 +3,7 @@
 * This file is a part of the rekonq project
 *
 * Copyright (c) 2001 by Dawit Alemayehu <adawit@kde.org>
-* Copyright (C) 2010-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2010-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 *
 *
 * This program is free software; you can redistribute it and/or
@@ -41,21 +41,18 @@
 
 #include <KProtocolManager>
 
+// Qt includes
+#include <QStringBuilder>
 
 UserAgentInfo::UserAgentInfo()
 {
-    /*    KService::List m_providers = KServiceTypeTrader::self()->query("UserAgentStrings");*/
+    m_providers = KServiceTypeTrader::self()->query("UserAgentStrings");
+}
 
-    // NOTE: limiting User Agent Numbers
-    m_providers << KService::serviceByDesktopName("firefox36oncurrent");
-    m_providers << KService::serviceByDesktopName("ie70onwinnt51");
-    m_providers << KService::serviceByDesktopName("ie60oncurrent");
-    m_providers << KService::serviceByDesktopName("chrome50oncurrent");
-    m_providers << KService::serviceByDesktopName("safari40");
-    m_providers << KService::serviceByDesktopName("op962oncurrent");
-    m_providers << KService::serviceByDesktopName("ns71oncurrent");
-    m_providers << KService::serviceByDesktopName("android10");
-    m_providers << KService::serviceByDesktopName("googlebot");
+
+KService::List UserAgentInfo::availableProviders() const
+{
+    return m_providers;
 }
 
 
@@ -128,10 +125,16 @@ QString UserAgentInfo::userAgentDescription(int i)
         return QL1S("Default");
     }
 
-    QString tmp = m_providers.at(i)->property("Name").toString();
-    tmp.remove(QL1S("UADescription ("));
-    tmp.remove(QL1C(')'));
-    return tmp;
+    QString systemName = m_providers.at(i)->property("X-KDE-UA-SYSNAME").toString();
+    QString systemRelease = m_providers.at(i)->property("X-KDE-UA-SYSRELEASE").toString();
+    QString systemSummary;
+
+    if (!systemName.isEmpty() && !systemRelease.isEmpty())
+    {
+        systemSummary = i18nc("describe UA platform, eg: firefox 3.1 \"on Windows XP\"", " on %1 %2", systemName, systemRelease);
+    }
+
+    return userAgentName(i) % QL1C(' ') % userAgentVersion(i) % systemSummary;
 }
 
 
@@ -193,7 +196,6 @@ bool UserAgentInfo::providerExists(int i)
     KService::Ptr s = m_providers.at(i);
     if (s.isNull())
     {
-        //FIXME Add me when string freeze has been reopened: KMessageBox::error(...)
         return false;
     }
     return true;
