@@ -70,7 +70,8 @@
 #include <kparts/browseropenorsavequestion.h>
 
 // Qt Includes
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
+#include <QFileInfo>
 
 
 // Returns true if the scheme and domain of the two urls match...
@@ -500,6 +501,10 @@ void WebPage::manageNetworkErrors(QNetworkReply *reply)
         break;
 
     case QNetworkReply::UnknownNetworkError:                 // unknown network-related error detected
+        // last chance for the strange things (eg: FTP, custom schemes, etc...)
+        if (_protHandler.postHandling(reply->request(), mainFrame()))
+            return;
+        
     case QNetworkReply::ConnectionRefusedError:              // remote server refused connection
     case QNetworkReply::HostNotFoundError:                   // invalid hostname
     case QNetworkReply::TimeoutError:                        // connection time out
