@@ -3,7 +3,7 @@
 * This file is a part of the rekonq project
 *
 * Copyright (C) 2009 Nokia Corporation <qt-info@nokia.com>
-* Copyright (C) 2009-2011 by Andrea Diamantini <adjam7 at gmail dot com>
+* Copyright (C) 2009-2012 by Andrea Diamantini <adjam7 at gmail dot com>
 * Copyright (C) 2010 by Matthieu Gicquel <matgic78 at gmail dot com>
 *
 *
@@ -30,23 +30,20 @@
 #include "websnap.h"
 #include "websnap.moc"
 
-// Local Includes
-#include "newtabpage.h"
-
 // KDE Includes
 #include <KStandardDirs>
 
 // Qt Includes
-#include <QtCore/QSize>
-#include <QtCore/QFile>
+#include <QSize>
+#include <QFile>
 
 #include <QCryptographicHash>
 
-#include <QtGui/QPainter>
-#include <QtGui/QAction>
+#include <QPainter>
+#include <QAction>
 
-#include <QtWebKit/QWebFrame>
-#include <QtWebKit/QWebSettings>
+#include <QWebFrame>
+#include <QWebSettings>
 
 
 WebSnap::WebSnap(const KUrl& url, QObject *parent)
@@ -95,42 +92,43 @@ QPixmap WebSnap::render(const QWebPage &page, int w, int h)
 }
 
 
-QPixmap WebSnap::renderTabPreview(const QWebPage &page, int w, int h)
-{
-    QSize oldSize = page.viewportSize();
-    int width = page.mainFrame()->contentsSize().width();
-    page.setViewportSize(QSize(width, width * ((0.0 + h) / w)));
-    QPixmap pageImage = WebSnap::render(page, page.viewportSize().width(), page.viewportSize().height());
-    page.setViewportSize(oldSize);
-    return pageImage.scaled(w, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
-}
-
-
-QPixmap WebSnap::renderClosingPagePreview(const QWebPage &page, int w, int h)
-{
-    //scroll to top
-    page.mainFrame()->setScrollBarValue(Qt::Vertical, 0);
-
-    // reduce as much as possible
-    page.setViewportSize(QSize(10, 10));
-
-    return renderPagePreview(page, w, h);
-}
-
-
+// NOTE
+// to render page preview in a safe way, you CANNOT work with scrollbars!
+// In fact, disabling temporarily them DOES NOT work without reloading a page
+// that is something we CANNOT do.
 QPixmap WebSnap::renderPagePreview(const QWebPage &page, int w, int h)
 {
-    //prepare page
-    page.mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
-    int width = page.mainFrame()->contentsSize().width();
-    page.setViewportSize(QSize(width, width * ((0.0 + h) / w)));
+    // store actual viewportsize
+    QSize oldSize = page.viewportSize();
 
-    //render
-    QPixmap pageImage = WebSnap::render(page, page.viewportSize().width(), page.viewportSize().height());
+    // prepare page
+    // NOTE: I saw some sites with strange CMS and with absurd content size width (eg: 8584553)
+    // This usually leads setViewportSize to crash :(
+    // So, ensure renderWidth is no more than 2000.
+    int renderWidth = page.mainFrame()->contentsSize().width();
+    if (renderWidth > 2000)
+        renderWidth = 2000;
+    int renderHeight = renderWidth * ((0.0 + h) / w);
+
+    page.setViewportSize(QSize(renderWidth, renderHeight));
+
+    // consider scrollbars and render the page
+    bool verticalScrollBarActive = !page.mainFrame()->scrollBarGeometry(Qt::Vertical).isEmpty();
+    if (verticalScrollBarActive)
+        renderWidth -= 15;
+
+    bool horizontalScrollBarActive = !page.mainFrame()->scrollBarGeometry(Qt::Horizontal).isEmpty();
+    if (horizontalScrollBarActive)
+        renderHeight -= 15;
+
+    QPixmap pageImage = WebSnap::render(page, renderWidth, renderHeight);
 
     // resize image
     pageImage = pageImage.scaled(w, h, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
 
+    // restore page state
+    page.setViewportSize(oldSize);
+
     return pageImage;
 }
 
